<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    マイクロブログ
 * @author     株式会社 毎日メディアサービス
 * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: chacha_mainProfileWidgetContainer.php 3238 2010-06-14 05:05:09Z fishbone $
 * @link       http://www.m-media.co.jp
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/chacha_mainBaseWidgetContainer.php');

class chacha_mainProfileWidgetContainer extends chacha_mainBaseWidgetContainer
{
	const DEFAULT_PAGE_TITLE = 'プロフィール';
	const MEMBER_ID_LENGTH = 5;		// 会員IDの桁数
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		return 'profile.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$act = $request->trimValueOf('act');
		$postTicket = $request->trimValueOf('ticket');		// POST確認用
		$memberId = $request->trimValueOf(self::URL_PARAM_MEMBER_ID);	// 会員ID

		// ##### ユーザの識別 #####
		// ユーザIDでユーザのプロフィールを参照。ユーザIDがない場合は自分自身のプロフィールを表示。
		// クライアントIDを取得
		$canEdit = false;			// データ編集可能かどうか
		$isNew = true;				// 新規登録かどうか
		$clientId = '';
		if ($this->gEnv->canUseCookie()){		// クッキー使用可能なとき
			$clientId = $this->gAccess->getClientId();
		} else {
			$this->setUserErrorMsg('クッキーを使用可にして下さい');
		}
		
		// 会員情報が登録されている場合は更新。登録されていない場合は新規登録。
		$ret = $this->_db->getMemberInfoByDeviceId($clientId, $row);
		if ($ret){		// 更新の場合
			if (empty($memberId)) $memberId = $row['mb_id'];
			if ($memberId == $row['mb_id']) $canEdit = true;		// 更新の場合は自分自身のプロフィールのみ更新可能
			$isNew = false;					// 更新処理
		} else {		// 新規の場合
			$canEdit = true;			// データ編集可能かどうか
		}

		$name = $request->trimValueOf('name');					// ユーザ名
		
		$reloadData = false;		// データの再読み込み
		if ($act == 'add'){		// 新規追加のとき
			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
				// 入力チェック
				$this->checkInput($name, 'ニックネーム');
				$this->checkInput($clientId, '端末ID');
			
				// エラーなしの場合は、データを登録
				if ($this->getMsgCount() == 0){
					// 会員ID作成
					$memberId = $this->createMemberId();
					if (empty($memberId)){
						$this->setAppErrorMsg('IDが作成できません');
					} else {
						// 一般ユーザの場合はユーザIDも登録
						$userId = 0;
						$userInfo = $this->gEnv->getCurrentUserInfo();
						if (!is_null($userInfo) && $userInfo->userType == UserInfo::USER_TYPE_NORMAL) $userId = $this->gEnv->getCurrentUserId();
						
						$ret = $this->_db->addMember($clientId, $memberId, $userId, $name, '');
						if ($ret){
							$this->setGuidanceMsg('登録完了しました');
							$reloadData = true;		// データの再読み込み
						}
					}
				}
			}
			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
		} else if ($act == 'update'){		// 設定更新のとき
			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
				// 入力チェック
				$this->checkInput($name, 'ニックネーム');
				$this->checkInput($clientId, '端末ID');
			
				// エラーなしの場合は、データを更新
				if ($this->getMsgCount() == 0){
					$ret = $this->_db->updateMember($clientId, $name, '', $newSerial);
					if ($ret){
						$this->setGuidanceMsg('更新完了しました');
						$reloadData = true;		// データの再読み込み
					}
				}
			}
			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
		} else {
			$reloadData = true;		// データの再読み込み
		}
		
		// データの再取得
		if ($reloadData){
			$ret = $this->_db->getMemberInfoById($memberId, $row);
			if ($ret){
				$name = $row['mb_name'];		// ユーザ名
			}
		}
		
		// 表示設定
		$makeThreadStyle = self::CSS_BLOG_INNER_STYLE;
		$makeThreadColor = $this->_configArray[self::CF_PROFILE_COLOR];		// プロフィール背景色
		if (empty($makeThreadColor)) $makeThreadColor = $this->_configArray[self::CF_INNER_BG_COLOR];		// デフォルトの内枠背景色
		if (!empty($makeThreadColor)) $makeThreadStyle .= 'background-color:' . $makeThreadColor . ';';
		$this->tmpl->addVar("_widget", "make_thread_style", $makeThreadStyle);
		
		$this->tmpl->addVar("_widget", "page_title", self::DEFAULT_PAGE_TITLE);		// ページタイトル
		$this->tmpl->addVar("_widget", "name", $name);		// ユーザ名
		$memberIdStr = '';
		if (!empty($memberId)){
			$mypageLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId, true));
			$memberIdStr = '<a href="' . $mypageLink . '">' . $this->convertToDispString($memberId) . '</a>';
		}
		$this->tmpl->addVar("_widget", "id", $memberIdStr);		// マイブログページへのリンク
		
		// 編集状態の設定
		if ($canEdit){		// 編集可の場合
			// ハッシュキー作成
			$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
			$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
			$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
				
			if ($isNew){		// 新規登録のとき
				$this->tmpl->setAttribute('add_area', 'visibility', 'visible');// 新規登録ボタン表示
			} else {
				$this->tmpl->setAttribute('update_area', 'visibility', 'visible');// 更新ボタン表示
			}
			
			// マイページへのリンクを表示
			$this->tmpl->setAttribute('top_link_area', 'visibility', 'visible');
			$this->tmpl->addVar("top_link_area", "mypage_url", $mypageLink);			// マイページURL
		} else {
			$this->tmpl->addVar("_widget", "name_disabled", "disabled");		// ユーザ名
		}
	}
	/**
	 * 会員IDを作成
	 *
	 * @return string				会員ID
	 */
	function createMemberId()
	{
		$memberId = '';
		
		for ($i = 0; $i < self::CREATE_CODE_RETRY_COUNT; $i++){
			// 「0」除くランダム文字列を作成
			$memberId = $this->_createRandString('123456789', self::MEMBER_ID_LENGTH);
		
			// すでに登録済みかどうかチェック
			$ret = $this->_db->isExistsMemberId($memberId);
			if (!$ret) break;
		}
		return $memberId;
	}
}
?>
